////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  asf_3_2_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "asf_3_2_0.h"
#include "parametersetmanager.h"

ASF_3_2_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_hpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_hpf_symmetric_coeff_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_lpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_lpf_symmetric_coeff_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_normalization_lut_tab") == 0)
    {
        __result = layer_1_activity_normalization_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_weight_modulation_lut_tab") == 0)
    {
        __result = layer_1_weight_modulation_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_soft_threshold_lut_tab") == 0)
    {
        __result = layer_1_soft_threshold_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_positive_lut_tab") == 0)
    {
        __result = layer_1_gain_positive_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_negative_lut_tab") == 0)
    {
        __result = layer_1_gain_negative_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_weight_lut_tab") == 0)
    {
        __result = layer_1_gain_weight_lut_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gamma_corrected_luma_target") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_gamma_corrected_luma_target, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_cap") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_gain_cap, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ul") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_clamp_ul, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ll") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_clamp_ll, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_clamp_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_activity_clamp_threshold, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_upper_offset") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_median_blend_upper_offset, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_lower_offset") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_median_blend_lower_offset, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_sp") == 0)
    {
        ParameterUtils::DoubleToString((double)layer_1_sp, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "radial_activity_adj_tab") == 0)
    {
        __result = radial_activity_adj_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "radial_gain_adj_tab") == 0)
    {
        __result = radial_gain_adj_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_positive_tab") == 0)
    {
        __result = gain_contrast_positive_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_negative_tab") == 0)
    {
        __result = gain_contrast_negative_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "min_max_filter_coefficients_tab") == 0)
    {
        __result = min_max_filter_coefficients_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool asf32_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_hpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_hpf_symmetric_coeff_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_lpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_lpf_symmetric_coeff_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_normalization_lut_tab") == 0)
    {
        __result = layer_1_activity_normalization_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_weight_modulation_lut_tab") == 0)
    {
        __result = layer_1_weight_modulation_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_soft_threshold_lut_tab") == 0)
    {
        __result = layer_1_soft_threshold_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_positive_lut_tab") == 0)
    {
        __result = layer_1_gain_positive_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_negative_lut_tab") == 0)
    {
        __result = layer_1_gain_negative_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_weight_lut_tab") == 0)
    {
        __result = layer_1_gain_weight_lut_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gamma_corrected_luma_target") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_gamma_corrected_luma_target = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_cap") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_gain_cap = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ul") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_clamp_ul = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ll") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_clamp_ll = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_clamp_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_activity_clamp_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_upper_offset") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_median_blend_upper_offset = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_lower_offset") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_median_blend_lower_offset = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_sp") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            layer_1_sp = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "radial_activity_adj_tab") == 0)
    {
        __result = radial_activity_adj_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "radial_gain_adj_tab") == 0)
    {
        __result = radial_gain_adj_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_positive_tab") == 0)
    {
        __result = gain_contrast_positive_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_negative_tab") == 0)
    {
        __result = gain_contrast_negative_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "min_max_filter_coefficients_tab") == 0)
    {
        __result = min_max_filter_coefficients_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool asf32_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_hpf_symmetric_coeff_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_hpf_symmetric_coeff_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_hpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_hpf_symmetric_coeff_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_lpf_symmetric_coeff_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_lpf_symmetric_coeff_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_lpf_symmetric_coeff_tab") == 0)
    {
        __result = layer_1_lpf_symmetric_coeff_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_activity_normalization_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_activity_normalization_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_normalization_lut_tab") == 0)
    {
        __result = layer_1_activity_normalization_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_weight_modulation_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_weight_modulation_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_weight_modulation_lut_tab") == 0)
    {
        __result = layer_1_weight_modulation_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_soft_threshold_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_soft_threshold_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_soft_threshold_lut_tab") == 0)
    {
        __result = layer_1_soft_threshold_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_gain_positive_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_positive_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_positive_lut_tab") == 0)
    {
        __result = layer_1_gain_positive_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_gain_negative_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_negative_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_negative_lut_tab") == 0)
    {
        __result = layer_1_gain_negative_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_gain_weight_lut_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_weight_lut_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_weight_lut_tab") == 0)
    {
        __result = layer_1_gain_weight_lut_tab.GetInfo(&__path[__pos], __info);
    }

    // layer_1_gamma_corrected_luma_target
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gamma_corrected_luma_target", ParameterParserDataType::Int32, (double)layer_1_gamma_corrected_luma_target, 0));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gamma_corrected_luma_target") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)layer_1_gamma_corrected_luma_target, 0));
    }

    // layer_1_gain_cap
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_cap", ParameterParserDataType::Float, (double)layer_1_gain_cap));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_gain_cap") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)layer_1_gain_cap));
    }

    // layer_1_clamp_ul
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_clamp_ul", ParameterParserDataType::Int32, (double)layer_1_clamp_ul, 0));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ul") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)layer_1_clamp_ul, 0));
    }

    // layer_1_clamp_ll
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_clamp_ll", ParameterParserDataType::Int32, (double)layer_1_clamp_ll, 0));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_clamp_ll") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)layer_1_clamp_ll, 0));
    }

    // layer_1_activity_clamp_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_activity_clamp_threshold", ParameterParserDataType::Int32, (double)layer_1_activity_clamp_threshold, 0));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_activity_clamp_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)layer_1_activity_clamp_threshold, 0));
    }

    // layer_1_median_blend_upper_offset
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_median_blend_upper_offset", ParameterParserDataType::Float, (double)layer_1_median_blend_upper_offset));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_upper_offset") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)layer_1_median_blend_upper_offset));
    }

    // layer_1_median_blend_lower_offset
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_median_blend_lower_offset", ParameterParserDataType::Float, (double)layer_1_median_blend_lower_offset));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_median_blend_lower_offset") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)layer_1_median_blend_lower_offset));
    }

    // layer_1_sp
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_sp", ParameterParserDataType::UInt32, (double)layer_1_sp, 0));
    }
    else if (PARAMETER_STRCMP(__name, "layer_1_sp") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)layer_1_sp, 0));
    }

    // radial_activity_adj_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_activity_adj_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "radial_activity_adj_tab") == 0)
    {
        __result = radial_activity_adj_tab.GetInfo(&__path[__pos], __info);
    }

    // radial_gain_adj_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_gain_adj_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "radial_gain_adj_tab") == 0)
    {
        __result = radial_gain_adj_tab.GetInfo(&__path[__pos], __info);
    }

    // gain_contrast_positive_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gain_contrast_positive_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_positive_tab") == 0)
    {
        __result = gain_contrast_positive_tab.GetInfo(&__path[__pos], __info);
    }

    // gain_contrast_negative_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gain_contrast_negative_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gain_contrast_negative_tab") == 0)
    {
        __result = gain_contrast_negative_tab.GetInfo(&__path[__pos], __info);
    }

    // min_max_filter_coefficients_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_max_filter_coefficients_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "min_max_filter_coefficients_tab") == 0)
    {
        __result = min_max_filter_coefficients_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_hpf_symmetric_coeff_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_hpf_symmetric_coeff") == 0)
    {
        if (__index < 10)
        {
            ParameterUtils::DoubleToString((double)layer_1_hpf_symmetric_coeff[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 10; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_hpf_symmetric_coeff[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_hpf_symmetric_coeff_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_hpf_symmetric_coeff") == 0)
    {
        if (__index < 10)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_hpf_symmetric_coeff[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 10)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_hpf_symmetric_coeff[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_hpf_symmetric_coeff_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_hpf_symmetric_coeff
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_hpf_symmetric_coeff", ParameterParserDataType::Int32, true, false, 10));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_lpf_symmetric_coeff_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_lpf_symmetric_coeff") == 0)
    {
        if (__index < 10)
        {
            ParameterUtils::DoubleToString((double)layer_1_lpf_symmetric_coeff[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 10; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_lpf_symmetric_coeff[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_lpf_symmetric_coeff_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_lpf_symmetric_coeff") == 0)
    {
        if (__index < 10)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_lpf_symmetric_coeff[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 10)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_lpf_symmetric_coeff[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_lpf_symmetric_coeff_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_lpf_symmetric_coeff
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_lpf_symmetric_coeff", ParameterParserDataType::Int32, true, false, 10));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_activity_normalization_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_activity_normalization_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_activity_normalization_lut[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_activity_normalization_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_activity_normalization_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_activity_normalization_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_activity_normalization_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_activity_normalization_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_activity_normalization_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_activity_normalization_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_activity_normalization_lut", ParameterParserDataType::Float, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_weight_modulation_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_weight_modulation_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_weight_modulation_lut[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_weight_modulation_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_weight_modulation_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_weight_modulation_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_weight_modulation_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_weight_modulation_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_weight_modulation_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_weight_modulation_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_weight_modulation_lut", ParameterParserDataType::Float, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_soft_threshold_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_soft_threshold_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_soft_threshold_lut[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_soft_threshold_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_soft_threshold_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_soft_threshold_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_soft_threshold_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_soft_threshold_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_soft_threshold_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_soft_threshold_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_soft_threshold_lut", ParameterParserDataType::UInt32, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_positive_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_positive_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_gain_positive_lut[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_gain_positive_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_positive_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_positive_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_gain_positive_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_gain_positive_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_positive_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_gain_positive_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_positive_lut", ParameterParserDataType::Float, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_negative_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_negative_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_gain_negative_lut[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_gain_negative_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_negative_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_negative_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_gain_negative_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_gain_negative_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_negative_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_gain_negative_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_negative_lut", ParameterParserDataType::Float, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_weight_lut_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_weight_lut") == 0)
    {
        if (__index < 64)
        {
            ParameterUtils::DoubleToString((double)layer_1_gain_weight_lut[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 64; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)layer_1_gain_weight_lut[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_weight_lut_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "layer_1_gain_weight_lut") == 0)
    {
        if (__index < 64)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                layer_1_gain_weight_lut[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 64)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    layer_1_gain_weight_lut[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::layer_1_gain_weight_lut_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // layer_1_gain_weight_lut
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("layer_1_gain_weight_lut", ParameterParserDataType::Float, true, false, 64));
    }

    return __result;
}

bool asf32_rgn_dataType::radial_activity_adj_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_activity_adj") == 0)
    {
        if (__index < 4)
        {
            ParameterUtils::DoubleToString((double)radial_activity_adj[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 4; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)radial_activity_adj[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::radial_activity_adj_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_activity_adj") == 0)
    {
        if (__index < 4)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                radial_activity_adj[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 4)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    radial_activity_adj[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::radial_activity_adj_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_activity_adj
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_activity_adj", ParameterParserDataType::Float, true, false, 4));
    }

    return __result;
}

bool asf32_rgn_dataType::radial_gain_adj_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_gain_adj") == 0)
    {
        if (__index < 4)
        {
            ParameterUtils::DoubleToString((double)radial_gain_adj[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 4; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)radial_gain_adj[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::radial_gain_adj_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_gain_adj") == 0)
    {
        if (__index < 4)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                radial_gain_adj[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 4)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    radial_gain_adj[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::radial_gain_adj_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_gain_adj
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_gain_adj", ParameterParserDataType::Float, true, false, 4));
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_positive_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gain_contrast_positive") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)gain_contrast_positive[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gain_contrast_positive[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_positive_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gain_contrast_positive") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gain_contrast_positive[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gain_contrast_positive[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_positive_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gain_contrast_positive
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gain_contrast_positive", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_negative_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gain_contrast_negative") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)gain_contrast_negative[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)gain_contrast_negative[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_negative_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gain_contrast_negative") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                gain_contrast_negative[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    gain_contrast_negative[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::gain_contrast_negative_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gain_contrast_negative
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gain_contrast_negative", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool asf32_rgn_dataType::min_max_filter_coefficients_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "min_max_filter_coefficients") == 0)
    {
        if (__index < 5)
        {
            ParameterUtils::DoubleToString((double)min_max_filter_coefficients[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 5; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)min_max_filter_coefficients[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::min_max_filter_coefficients_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "min_max_filter_coefficients") == 0)
    {
        if (__index < 5)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                min_max_filter_coefficients[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 5)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    min_max_filter_coefficients[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool asf32_rgn_dataType::min_max_filter_coefficients_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // min_max_filter_coefficients
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_max_filter_coefficients", ParameterParserDataType::UInt32, true, false, 5));
    }

    return __result;
}

bool mod_asf32_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "asf32_rgn_data") == 0)
    {
        __result = asf32_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_asf32_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "asf32_rgn_data") == 0)
    {
        __result = asf32_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_asf32_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // asf32_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("asf32_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "asf32_rgn_data") == 0)
    {
        __result = asf32_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_aec_data") == 0)
    {
        if (__index < mod_asf32_aec_dataCount)
        {
            __result = mod_asf32_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_aec_data") == 0)
    {
        if (__index < mod_asf32_aec_dataCount)
        {
            __result = mod_asf32_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_asf32_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_asf32_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_asf32_aec_data", ParameterParserDataType::Structure, true, false, mod_asf32_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_asf32_aec_data") == 0)
    {
        if (__index < mod_asf32_aec_dataCount)
        {
            __result = mod_asf32_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_asf32_aec_dataCount));
        }
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_hdr_aec_data") == 0)
    {
        if (__index < mod_asf32_hdr_aec_dataCount)
        {
            __result = mod_asf32_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_hdr_aec_data") == 0)
    {
        if (__index < mod_asf32_hdr_aec_dataCount)
        {
            __result = mod_asf32_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_asf32_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_asf32_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_asf32_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_asf32_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_asf32_hdr_aec_data") == 0)
    {
        if (__index < mod_asf32_hdr_aec_dataCount)
        {
            __result = mod_asf32_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_asf32_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // total_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("total_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_trigger") == 0)
    {
        __result = total_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // total_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("total_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "total_scale_ratio_data") == 0)
    {
        __result = total_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::total_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_drc_gain_data") == 0)
    {
        if (__index < mod_asf32_drc_gain_dataCount)
        {
            __result = mod_asf32_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::total_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_drc_gain_data") == 0)
    {
        if (__index < mod_asf32_drc_gain_dataCount)
        {
            __result = mod_asf32_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_asf32_total_scale_ratio_dataType::total_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_asf32_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_asf32_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_asf32_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_asf32_drc_gain_data") == 0)
    {
        if (__index < mod_asf32_drc_gain_dataCount)
        {
            __result = mod_asf32_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_asf32_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_asf32_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_total_scale_ratio_data") == 0)
    {
        if (__index < mod_asf32_total_scale_ratio_dataCount)
        {
            __result = mod_asf32_total_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_asf32_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_asf32_total_scale_ratio_data") == 0)
    {
        if (__index < mod_asf32_total_scale_ratio_dataCount)
        {
            __result = mod_asf32_total_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_asf32_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_asf32_total_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_asf32_total_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_asf32_total_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_asf32_total_scale_ratio_data") == 0)
    {
        if (__index < mod_asf32_total_scale_ratio_dataCount)
        {
            __result = mod_asf32_total_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_asf32_total_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool chromatix_asf32_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "radial_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)radial_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "contrast_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)contrast_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_asf32_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "radial_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            radial_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "contrast_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            contrast_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_asf32_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_anchor_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_anchor_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "radial_anchor_tab") == 0)
    {
        __result = radial_anchor_tab.GetInfo(&__path[__pos], __info);
    }

    // radial_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_enable", ParameterParserDataType::Int32, (double)radial_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "radial_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)radial_enable, 0));
    }

    // contrast_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("contrast_enable", ParameterParserDataType::Int32, (double)contrast_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "contrast_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)contrast_enable, 0));
    }

    return __result;
}

bool chromatix_asf32_reserveType::radial_anchor_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor") == 0)
    {
        if (__index < 4)
        {
            ParameterUtils::DoubleToString((double)radial_anchor[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 4; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)radial_anchor[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_asf32_reserveType::radial_anchor_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "radial_anchor") == 0)
    {
        if (__index < 4)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                radial_anchor[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 4)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    radial_anchor[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_asf32_reserveType::radial_anchor_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // radial_anchor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("radial_anchor", ParameterParserDataType::Float, true, false, 4));
    }

    return __result;
}

bool chromatix_asf32Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_reserve") == 0)
    {
        __result = chromatix_asf32_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_core") == 0)
    {
        __result = chromatix_asf32_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_asf32Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_reserve") == 0)
    {
        __result = chromatix_asf32_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_core") == 0)
    {
        __result = chromatix_asf32_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_asf32Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // dynamic_enable_triggers
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dynamic_enable_triggers", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dynamic_enable_triggers") == 0)
    {
        __result = dynamic_enable_triggers.GetInfo(&__path[__pos], __info);
    }

    // chromatix_asf32_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_asf32_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_reserve") == 0)
    {
        __result = chromatix_asf32_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_asf32_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_asf32_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_asf32_core") == 0)
    {
        __result = chromatix_asf32_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_asf32Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)asf_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_asf32Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            asf_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_asf32Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // asf_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("asf_enable", ParameterParserDataType::Int32, (double)asf_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)asf_enable, 0));
    }

    return __result;
}

bool chromatix_asf32Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_asf32Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_asf32Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_asf32Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_asf32Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_asf32Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_asf32Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 4)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 4; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_asf32Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 4)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 4)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_asf32Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 4));
    }

    return __result;
}

bool chromatix_asf32Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_asf32Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_asf32Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        __result = asf_enable.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        __result = asf_enable.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // asf_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("asf_enable", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "asf_enable") == 0)
    {
        __result = asf_enable.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::asf_enableStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_control_var, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)hyst_mode, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::asf_enableStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_control_var = (ispglobalelements::control_var_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            hyst_mode = (ispglobalelements::hyst_direction)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_asf32Type::dynamic_enable_triggersStruct::asf_enableStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Int32, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enable, 0));
    }

    // hyst_control_var
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_control_var", ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_control_var") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_control_var, 0));
    }

    // hyst_mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_mode", ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)hyst_mode, 0));
    }

    // hyst_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hyst_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hyst_trigger") == 0)
    {
        __result = hyst_trigger.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_asf32Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_total_scale_ratio):
            enumValue = chromatix_asf32Type::control_variablesStruct::control_var_typeEnum::control_total_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_asf32Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_asf32TypeClass::chromatix_asf32TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_asf32_reserve);
    PARAMETER_INITIALIZE(chromatix_asf32_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_asf32TypeClass::chromatix_asf32TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_asf32_reserve);
    PARAMETER_INITIALIZE(chromatix_asf32_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_asf32TypeClass::~chromatix_asf32TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_asf32TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "asf32_ope")) == 0)
    {
        name = "asf32_ope";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_hpf_symmetric_coeff_tab);
    PARAMETER_INITIALIZE(layer_1_lpf_symmetric_coeff_tab);
    PARAMETER_INITIALIZE(layer_1_activity_normalization_lut_tab);
    PARAMETER_INITIALIZE(layer_1_weight_modulation_lut_tab);
    PARAMETER_INITIALIZE(layer_1_soft_threshold_lut_tab);
    PARAMETER_INITIALIZE(layer_1_gain_positive_lut_tab);
    PARAMETER_INITIALIZE(layer_1_gain_negative_lut_tab);
    PARAMETER_INITIALIZE(layer_1_gain_weight_lut_tab);
    PARAMETER_INITIALIZE(layer_1_gamma_corrected_luma_target);
    PARAMETER_INITIALIZE(layer_1_gain_cap);
    PARAMETER_INITIALIZE(layer_1_clamp_ul);
    PARAMETER_INITIALIZE(layer_1_clamp_ll);
    PARAMETER_INITIALIZE(layer_1_activity_clamp_threshold);
    PARAMETER_INITIALIZE(layer_1_median_blend_upper_offset);
    PARAMETER_INITIALIZE(layer_1_median_blend_lower_offset);
    PARAMETER_INITIALIZE(layer_1_sp);
    PARAMETER_INITIALIZE(radial_activity_adj_tab);
    PARAMETER_INITIALIZE(radial_gain_adj_tab);
    PARAMETER_INITIALIZE(gain_contrast_positive_tab);
    PARAMETER_INITIALIZE(gain_contrast_negative_tab);
    PARAMETER_INITIALIZE(min_max_filter_coefficients_tab);

    result = layer_1_hpf_symmetric_coeff_tab.Load(entry, alignment);
    if (result)
    {
        result = layer_1_lpf_symmetric_coeff_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_activity_normalization_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_weight_modulation_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_soft_threshold_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_gain_positive_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_gain_negative_lut_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = layer_1_gain_weight_lut_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_gamma_corrected_luma_target, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_gain_cap, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_clamp_ul, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_clamp_ll, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_activity_clamp_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_median_blend_upper_offset, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_median_blend_lower_offset, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, layer_1_sp, alignment)
    if (result)
    {
        result = radial_activity_adj_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = radial_gain_adj_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gain_contrast_positive_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = gain_contrast_negative_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = min_max_filter_coefficients_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_hpf_symmetric_coeff_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_hpf_symmetric_coeff_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_hpf_symmetric_coeff);

    result = entry->ReadArray(layer_1_hpf_symmetric_coeff, 10, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_lpf_symmetric_coeff_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_lpf_symmetric_coeff_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_lpf_symmetric_coeff);

    result = entry->ReadArray(layer_1_lpf_symmetric_coeff, 10, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_activity_normalization_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_activity_normalization_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_activity_normalization_lut);

    result = entry->ReadArray(layer_1_activity_normalization_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_weight_modulation_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_weight_modulation_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_weight_modulation_lut);

    result = entry->ReadArray(layer_1_weight_modulation_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_soft_threshold_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_soft_threshold_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_soft_threshold_lut);

    result = entry->ReadArray(layer_1_soft_threshold_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_gain_positive_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_gain_positive_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_gain_positive_lut);

    result = entry->ReadArray(layer_1_gain_positive_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_gain_negative_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_gain_negative_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_gain_negative_lut);

    result = entry->ReadArray(layer_1_gain_negative_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_layer_1_gain_weight_lut_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::layer_1_gain_weight_lut_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(layer_1_gain_weight_lut);

    result = entry->ReadArray(layer_1_gain_weight_lut, 64, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_radial_activity_adj_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::radial_activity_adj_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_activity_adj);

    result = entry->ReadArray(radial_activity_adj, 4, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_radial_gain_adj_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::radial_gain_adj_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_gain_adj);

    result = entry->ReadArray(radial_gain_adj, 4, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_gain_contrast_positive_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::gain_contrast_positive_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gain_contrast_positive);

    result = entry->ReadArray(gain_contrast_positive, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_gain_contrast_negative_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::gain_contrast_negative_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gain_contrast_negative);

    result = entry->ReadArray(gain_contrast_negative, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load asf32_rgn_dataType_min_max_filter_coefficients_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool asf32_rgn_dataType::min_max_filter_coefficients_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(min_max_filter_coefficients);

    result = entry->ReadArray(min_max_filter_coefficients, 5, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(asf32_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = asf32_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_asf32_aec_data);


    // Reading Array mod_asf32_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_asf32_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_asf32_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_asf32_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_asf32_aec_dataDupInfo = pointerEntry->GetDupObject(mod_asf32_aec_dataCount, file, line);
            if (mod_asf32_aec_dataDupInfo != nullptr && mod_asf32_aec_dataDupInfo->Object != nullptr)
            {
                mod_asf32_aec_data = (mod_asf32_aec_dataType*)mod_asf32_aec_dataDupInfo->Object;
                if (mod_asf32_aec_data == nullptr)
                {
                    if (mod_asf32_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_asf32_aec_dataDupInfo->File, mod_asf32_aec_dataDupInfo->Line, mod_asf32_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_asf32_aec_dataDupInfo->Line, mod_asf32_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_asf32_aec_data == nullptr)
            {
                if (result && mod_asf32_aec_dataCount > 0)
                {
                    mod_asf32_aec_data = PARAMETER_NEW mod_asf32_aec_dataType[mod_asf32_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_asf32_aec_data, mod_asf32_aec_dataCount, file, line);
                }
                if (!result || mod_asf32_aec_data == nullptr)
                {
                    if (mod_asf32_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_asf32_aec_data\n");
                    }
                    mod_asf32_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_asf32_aec_dataCount; i++)
                {
                    result = mod_asf32_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_asf32_aec_data == nullptr)
        {
            mod_asf32_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_asf32_hdr_aec_data);


    // Reading Array mod_asf32_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_asf32_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_asf32_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_asf32_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_asf32_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_asf32_hdr_aec_dataCount, file, line);
            if (mod_asf32_hdr_aec_dataDupInfo != nullptr && mod_asf32_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_asf32_hdr_aec_data = (mod_asf32_hdr_aec_dataType*)mod_asf32_hdr_aec_dataDupInfo->Object;
                if (mod_asf32_hdr_aec_data == nullptr)
                {
                    if (mod_asf32_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_asf32_hdr_aec_dataDupInfo->File, mod_asf32_hdr_aec_dataDupInfo->Line, mod_asf32_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_asf32_hdr_aec_dataDupInfo->Line, mod_asf32_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_asf32_hdr_aec_data == nullptr)
            {
                if (result && mod_asf32_hdr_aec_dataCount > 0)
                {
                    mod_asf32_hdr_aec_data = PARAMETER_NEW mod_asf32_hdr_aec_dataType[mod_asf32_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_asf32_hdr_aec_data, mod_asf32_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_asf32_hdr_aec_data == nullptr)
                {
                    if (mod_asf32_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_asf32_hdr_aec_data\n");
                    }
                    mod_asf32_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_asf32_hdr_aec_dataCount; i++)
                {
                    result = mod_asf32_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_asf32_hdr_aec_data == nullptr)
        {
            mod_asf32_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_total_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_total_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(total_scale_ratio_trigger);
    PARAMETER_INITIALIZE(total_scale_ratio_data);

    result = total_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = total_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_asf32_total_scale_ratio_dataType_total_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_asf32_total_scale_ratio_dataType::total_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_asf32_drc_gain_data);


    // Reading Array mod_asf32_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_asf32_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_asf32_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_asf32_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_asf32_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_asf32_drc_gain_dataCount, file, line);
            if (mod_asf32_drc_gain_dataDupInfo != nullptr && mod_asf32_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_asf32_drc_gain_data = (mod_asf32_drc_gain_dataType*)mod_asf32_drc_gain_dataDupInfo->Object;
                if (mod_asf32_drc_gain_data == nullptr)
                {
                    if (mod_asf32_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_asf32_drc_gain_dataDupInfo->File, mod_asf32_drc_gain_dataDupInfo->Line, mod_asf32_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_asf32_drc_gain_dataDupInfo->Line, mod_asf32_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_asf32_drc_gain_data == nullptr)
            {
                if (result && mod_asf32_drc_gain_dataCount > 0)
                {
                    mod_asf32_drc_gain_data = PARAMETER_NEW mod_asf32_drc_gain_dataType[mod_asf32_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_asf32_drc_gain_data, mod_asf32_drc_gain_dataCount, file, line);
                }
                if (!result || mod_asf32_drc_gain_data == nullptr)
                {
                    if (mod_asf32_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_asf32_drc_gain_data\n");
                    }
                    mod_asf32_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_asf32_drc_gain_dataCount; i++)
                {
                    result = mod_asf32_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_asf32_drc_gain_data == nullptr)
        {
            mod_asf32_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_asf32_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_asf32_total_scale_ratio_data);


    // Reading Array mod_asf32_total_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_asf32_total_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_asf32_total_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_asf32_total_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_asf32_total_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_asf32_total_scale_ratio_dataCount, file, line);
            if (mod_asf32_total_scale_ratio_dataDupInfo != nullptr && mod_asf32_total_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_asf32_total_scale_ratio_data = (mod_asf32_total_scale_ratio_dataType*)mod_asf32_total_scale_ratio_dataDupInfo->Object;
                if (mod_asf32_total_scale_ratio_data == nullptr)
                {
                    if (mod_asf32_total_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_total_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_asf32_total_scale_ratio_dataDupInfo->File, mod_asf32_total_scale_ratio_dataDupInfo->Line, mod_asf32_total_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_asf32_total_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_asf32_total_scale_ratio_dataDupInfo->Line, mod_asf32_total_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_asf32_total_scale_ratio_data == nullptr)
            {
                if (result && mod_asf32_total_scale_ratio_dataCount > 0)
                {
                    mod_asf32_total_scale_ratio_data = PARAMETER_NEW mod_asf32_total_scale_ratio_dataType[mod_asf32_total_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_asf32_total_scale_ratio_data, mod_asf32_total_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_asf32_total_scale_ratio_data == nullptr)
                {
                    if (mod_asf32_total_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_asf32_total_scale_ratio_data\n");
                    }
                    mod_asf32_total_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_asf32_total_scale_ratio_dataCount; i++)
                {
                    result = mod_asf32_total_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_asf32_total_scale_ratio_data == nullptr)
        {
            mod_asf32_total_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_asf32_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_anchor_tab);
    PARAMETER_INITIALIZE(radial_enable);
    PARAMETER_INITIALIZE(contrast_enable);

    result = radial_anchor_tab.Load(entry, alignment);
    SYMBOL_TABLE_ENTRY_READ(entry, result, radial_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, contrast_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_asf32_reserveType_radial_anchor_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32_reserveType::radial_anchor_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(radial_anchor);

    result = entry->ReadArray(radial_anchor, 4, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_asf32Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(dynamic_enable_triggers);
    PARAMETER_INITIALIZE(chromatix_asf32_reserve);
    PARAMETER_INITIALIZE(chromatix_asf32_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = dynamic_enable_triggers.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_asf32_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_asf32_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(asf_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, asf_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 4; i++)
    {
        result = chromatix_asf32Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::dynamic_enable_triggersStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(asf_enable);

    result = asf_enable.Load(entry, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dynamic_enable_triggersStruct_asf_enableStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32Type::dynamic_enable_triggersStruct::asf_enableStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(hyst_control_var);
    PARAMETER_INITIALIZE(hyst_mode);
    PARAMETER_INITIALIZE(hyst_trigger);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    if (result)
    {
        result = ispglobalelements::ReadEnum_control_var_type(entry, hyst_control_var, alignment);
    }
    if (result)
    {
        result = ispglobalelements::ReadEnum_hyst_direction(entry, hyst_mode, alignment);
    }
    if (result)
    {
        result = hyst_trigger.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_asf32_aec_data))
    {
        PARAMETER_DELETE[] mod_asf32_aec_data;
    }
    mod_asf32_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_asf32_hdr_aec_dataCount; i++)
    {
        mod_asf32_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_asf32_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_asf32_hdr_aec_data;
    }
    mod_asf32_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_total_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_total_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    total_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_asf32_total_scale_ratio_dataType_total_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_asf32_total_scale_ratio_dataType::total_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_asf32_drc_gain_dataCount; i++)
    {
        mod_asf32_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_asf32_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_asf32_drc_gain_data;
    }
    mod_asf32_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_asf32_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_asf32_total_scale_ratio_dataCount; i++)
    {
        mod_asf32_total_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_asf32_total_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_asf32_total_scale_ratio_data;
    }
    mod_asf32_total_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_asf32Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_asf32_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32Type::Release()
{
    ((chromatix_asf32TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_asf32Type::GetModified()
{
    return ((chromatix_asf32TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_asf32TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_asf32TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_asf32TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_asf32TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_asf32TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_asf32TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_asf32TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_asf32TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_asf32TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_asf32TypeClass::Release()
{
    ParameterModule::Release();
}

ASF_3_2_0_NAMESPACE_END
